#!/bin/sh

UBOOTIMG=/usr/local/share/u-boot/2100/flash-image.bin
FLASHDEV=/dev/flash/spi0

if [ ! -c ${FLASHDEV} -o ! -f ${UBOOTIMG} ]; then
	echo "Cannot update the Netgate 2100 U-boot.  Invalid settings."
	exit 1
fi

echo "=> Updating the Netgate 2100 U-boot"
echo "==> Reading current settings"
/bin/rm -f /tmp/ubenv 2> /dev/null
/usr/local/sbin/u-boot-env-read /tmp/ubenv 2> /dev/null
if [ ! -f /tmp/ubenv ]; then
	echo "==> Warning: No settings were found"
fi
echo "==> Updating the U-boot image (this may take a few minutes)"
/bin/dd if=${UBOOTIMG} of=${FLASHDEV} bs=64k
if [ -f /tmp/ubenv ]; then
	echo "==> Updating settings"
	/bin/rm -f /tmp/ubenv-new 2> /dev/null
	/usr/local/sbin/u-boot-env-update /tmp/ubenv /tmp/ubenv-new 2> /dev/null
	if [ $? -ne 0 ]; then
		echo "==> Failed to update the settings"
		echo "==> Restoring current settings"
		config=/tmp/ubenv
	else
		echo "==> Restoring updated settings"
		config=/tmp/ubenv-new
	fi
	/usr/local/sbin/u-boot-env-write -yY ${config} 2> /dev/null
	if [ $? -ne 0 ]; then
		echo "Failed to restore the settings, U-boot will not work properly."
		echo "Saving original settings in /root/ubenv for later recovery."
		cp /tmp/ubenv /root/ubenv
	fi
	/bin/rm -f /tmp/ubenv /tmp/ubenv-new 2> /dev/null
fi
